#include <stdio.h>

#include "my_header.h"

int main(int argc, char *argv[]) {
    printf("C compiled.\n");
}